@@ -1,7 +1,7 @@
 package Module::Patch;
 
-our $DATE = '2018-02-18'; # DATE
-our $VERSION = '0.270'; # VERSION
+our $DATE = '2018-10-06'; # DATE
+our $VERSION = '0.271'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -116,6 +116,8 @@ sub import {
         my $pcdata = $pdata->{config} // {};
         my $config = \%{"$self\::config"};
         while (my ($k, $v) = each %$pcdata) {
+            die "Invalid configuration defined by $self\::patch_data(): ".
+                "$k: must start with dash" unless $k =~ /\A-/;
             $config->{$k} = $v->{default};
             if (exists $opts{$k}) {
                 $config->{$k} = $opts{$k};
@@ -285,7 +287,7 @@ Module::Patch - Patch package with a set of patches
 
 =head1 VERSION
 
-This document describes version 0.270 of Module::Patch (from Perl distribution Module-Patch), released on 2018-02-18.
+This document describes version 0.271 of Module::Patch (from Perl distribution Module-Patch), released on 2018-10-06.
 
 =head1 SYNOPSIS
 
@@ -322,13 +324,16 @@ To create a patch module by subclassing Module::Patch:
          v => 3,
          patches => [...], # $patches_spec
          config => { # per-patch-module config
-             a => {
-                 default => 1,
+             -foo => {                   # config name must start with a dash
+                 summary => 'blah blah',
+                 schema  => 'str*',      # Sah schema
+                 default => 'val',       # default value
              },
-             b => {},
-             c => {
-                 default => 3,
+             -bar => {
+                 schema  => 'int*',
+                 default => 2,
              },
+             ...
          },
      };
  }
@@ -337,14 +342,14 @@ To create a patch module by subclassing Module::Patch:
  # using your patch module
 
  use Some::Module::Patch::YourCategory
-     -force => 1, # optional, force patch even if target version does not match
-     -config => {a=>10, b=>20}, # optional, set config value
+     -force => 1,    # optional, force patch even if target version does not match
+     -foo => 'val2', # optional, specify configuration
  ;
 
  # accessing per-patch-module config data
 
- print $Some::Module::Patch::YourCategory::config->{a}; # 10
- print $Some::Module::Patch::YourCategory::config->{c}; # 3, default value
+ print $Some::Module::Patch::YourCategory::config{-foo}; # => 'val2'
+ print $Some::Module::Patch::YourCategory::config{-bar}; # 2, default value
 
  # unpatch, restore original subroutines
  no Some::Module::Patch::YourCategory;
